============
Installation
============

Dependencies
------------
The main dependency is `21cmFAST <https://github.com/21cmfast/21cmFAST/>`_
I *strongly* recommend you install ``21cmFAST`` first following the installation
instructions there.

Both ``21cmFAST`` and ``21cmfish`` must be installed in the same environment.

Installation
------------
At the command line::

    $ git clone git@github.com:charlottenosam/21cmfish.git
    $ cd 21cmfish
    $ pip install .
